import sqlite3
import asyncio
import nest_asyncio
nest_asyncio.apply()

from telegram import (
    Update, InlineKeyboardButton, InlineKeyboardMarkup,
    ReplyKeyboardMarkup, KeyboardButton, ReplyKeyboardRemove
)
from telegram.ext import (
    ApplicationBuilder, CommandHandler, CallbackQueryHandler,
    MessageHandler, filters, ConversationHandler, ContextTypes
)

# اتصال به دیتابیس
conn = sqlite3.connect('bot.db', check_same_thread=False)
c = conn.cursor()

# تعریف وضعیت‌ها
CHECK_CHANNEL_MEMBERSHIP, ASK_PHONE, CONFIRM_PAYMENT = range(3)
ENTRY_DATE, NIGHTS_COUNT, CUSTOM_NIGHTS_COUNT, ROOM_TYPE, MEAL_PLAN, CITY_SELECTION, HOTEL_SELECTION = range(3, 10)
TRANSPORT_SELECTION, TRANSPORT_DATE, TRANSPORT_TIME, TRANSPORT_PACKAGE, TRANSPORT_CONFIRM = range(10, 15)
ORIGIN_SELECTION, DESTINATION_SELECTION, PACKAGE_SELECTION, PACKAGE_DATE, PACKAGE_TIME = range(15, 20)
# وضعیت‌های جدید برای بخش سیم‌کارت
SIM_CARD_OPERATOR, SIM_CARD_SERVICE, SIM_CARD_PURCHASE, SIM_CARD_RECHARGE, SIM_CARD_CONFIRM = range(20, 25)

# تابع برای ساخت کیبورد اینلاین منوی اصلی (تب‌های حرفه‌ای)
def build_main_menu_keyboard():
    keyboard = [
        [
            InlineKeyboardButton("🏨 رزرو هتل", callback_data='start_reserve'),
            InlineKeyboardButton("🚗 حمل و نقل", callback_data='transportation')
        ],
        [
            InlineKeyboardButton("📱 سیم‌کارت", callback_data='sim_card')
        ],
        [
            InlineKeyboardButton("📞 پشتیبانی", callback_data='support'),
            InlineKeyboardButton("ℹ️ درباره ما", callback_data='about_us')
        ],
    ]
    return InlineKeyboardMarkup(keyboard)

# تابع برای ساخت کیبورد بازگشت به منوی اصلی
def build_back_to_menu_keyboard():
    return InlineKeyboardMarkup([[InlineKeyboardButton("🔙 بازگشت به منوی اصلی", callback_data='back_to_main')]])

# تابع برای ساخت کیبورد عضویت در کانال
def build_channel_membership_keyboard():
    keyboard = [
        [InlineKeyboardButton("📢 عضویت در کانال", url="https://t.me/your_channel_link")],  # لینک کانال خود را جایگزین کنید
        [InlineKeyboardButton("✅ عضو شدم", callback_data='joined_channel')]
    ]
    return InlineKeyboardMarkup(keyboard)

# تابع شروع ربات و درخواست عضویت در کانال
async def start(update: Update, context: ContextTypes.DEFAULT_TYPE):
    user_id = update.message.from_user.id
    # بررسی اینکه آیا کاربر قبلاً عضو شده یا خیر (می‌توانید از یک ستون در دیتابیس استفاده کنید)
    c.execute("SELECT phone_number FROM Users WHERE user_id=?", (user_id,))
    result = c.fetchone()

    if result and result[0]:
        await update.message.reply_text(
            "✅ خوش آمدید! شماره تلفن شما قبلاً ثبت شده است.\nلطفاً یکی از گزینه‌های زیر را انتخاب کنید:",
            reply_markup=build_main_menu_keyboard()
        )
        return ConversationHandler.END
    else:
        await update.message.reply_text(
            "🌟 خوش آمدید! برای استفاده از ربات، لطفاً ابتدا در کانال ما عضو شوید. پس از عضویت، روی 'عضو شدم' کلیک کنید.",
            reply_markup=build_channel_membership_keyboard()
        )
        return CHECK_CHANNEL_MEMBERSHIP

# تابع بررسی عضویت در کانال (اختیاری: می‌توانید منطق واقعی بررسی عضویت را اضافه کنید)
async def check_channel_membership(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    if query.data == 'joined_channel':
        # اینجا می‌توانید منطق بررسی واقعی عضویت در کانال را اضافه کنید
        # برای سادگی، فرض می‌کنیم کاربر با کلیک روی "عضو شدم" تأیید می‌شود
        await query.edit_message_text(
            "✅ عضویت شما تأیید شد! اکنون می‌توانید از ربات استفاده کنید.",
            reply_markup=None
        )
        keyboard = [[KeyboardButton("📞 ارسال شماره", request_contact=True)]]
        await query.message.reply_text(
            "لطفاً شماره موبایل خود را با دکمه زیر ارسال کنید:",
            reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True, resize_keyboard=True)
        )
        return ASK_PHONE
    return CHECK_CHANNEL_MEMBERSHIP

async def ask_for_phone(update: Update, context: ContextTypes.DEFAULT_TYPE):
    user_id = update.message.from_user.id
    c.execute("SELECT phone_number FROM Users WHERE user_id=?", (user_id,))
    result = c.fetchone()

    if result and result[0]:
        await update.message.reply_text(
            "✅ شماره تلفن شما قبلاً ثبت شده.\nلطفاً یکی از گزینه‌های زیر را انتخاب کنید:",
            reply_markup=build_main_menu_keyboard()
        )
        return ConversationHandler.END
    else:
        keyboard = [[KeyboardButton("📞 ارسال شماره", request_contact=True)]]
        await update.message.reply_text(
            "لطفاً شماره موبایل خود را با دکمه زیر ارسال کنید:",
            reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True, resize_keyboard=True)
        )
        return ASK_PHONE

async def save_phone(update: Update, context: ContextTypes.DEFAULT_TYPE):
    contact = update.message.contact
    if contact and contact.phone_number:
        user_id = update.message.from_user.id
        username = update.message.from_user.username or "ناشناس"
        phone = contact.phone_number

        c.execute("INSERT OR REPLACE INTO Users (user_id, username, phone_number) VALUES (?, ?, ?)",
                  (user_id, username, phone))
        conn.commit()

        await update.message.reply_text(
            "✅ شماره شما با موفقیت ثبت شد.\nلطفاً یکی از گزینه‌های زیر را انتخاب کنید:",
            reply_markup=build_main_menu_keyboard()
        )
        return ConversationHandler.END
    else:
        await update.message.reply_text("❌ مشکلی در دریافت شماره پیش آمد. لطفاً دوباره تلاش کنید.")
        return ASK_PHONE

async def show_main_menu(update: Update, context: ContextTypes.DEFAULT_TYPE, message_text="سلام! لطفاً یکی از گزینه‌های زیر را انتخاب کنید:"):
    """تابع برای نمایش منوی اصلی با تب‌های حرفه‌ای"""
    if hasattr(update, 'callback_query') and update.callback_query:
        await update.callback_query.edit_message_text(
            message_text,
            reply_markup=build_main_menu_keyboard()
        )
    else:
        await update.message.reply_text(
            message_text,
            reply_markup=build_main_menu_keyboard()
        )
    return ConversationHandler.END

async def start_reserve(update: Update, context: ContextTypes.DEFAULT_TYPE):
    await update.callback_query.answer()
    c.execute("SELECT DISTINCT city FROM Hotels")
    cities = c.fetchall()
    keyboard = [[InlineKeyboardButton(city[0], callback_data=f"select_city_{city[0]}")] for city in cities]
    keyboard.append([InlineKeyboardButton("🔙 بازگشت به منوی اصلی", callback_data="back_to_main")])
    await update.callback_query.edit_message_text(
        "لطفاً شهر را انتخاب کنید:",
        reply_markup=InlineKeyboardMarkup(keyboard)
    )
    return CITY_SELECTION

async def handle_city_selection(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    
    if query.data == "back_to_main":
        return await show_main_menu(update, context)
    
    city = query.data.replace("select_city_", "")
    c.execute("SELECT id, name FROM Hotels WHERE city=?", (city,))
    hotels = c.fetchall()
    keyboard = [[InlineKeyboardButton(h[1], callback_data=f"hotel_{h[0]}")] for h in hotels]
    keyboard.append([InlineKeyboardButton("🔙 بازگشت به انتخاب شهر", callback_data="start_reserve")])
    await query.edit_message_text(
        "هتل مورد نظر را انتخاب کنید:",
        reply_markup=InlineKeyboardMarkup(keyboard)
    )
    return HOTEL_SELECTION

async def handle_hotel_selection(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    
    if query.data == "start_reserve":
        return await start_reserve(update, context)
    
    hotel_id = int(query.data.split('_')[1])
    context.user_data['hotel_id'] = hotel_id

    c.execute("SELECT room_types, meal_options FROM Hotels WHERE id=?", (hotel_id,))
    result = c.fetchone()
    room_types = result[0].split(',') if result and result[0] else ["دو تخته", "سوئیت"]
    meal_options = result[1].split(',') if result and result[1] else ["با غذا", "بدون غذا"]

    context.user_data['room_type_options'] = room_types
    context.user_data['meal_options'] = meal_options

    keyboard = [["🔙 بازگشت"]]
    await query.message.reply_text(
        "تاریخ ورود را وارد کنید (مثلاً 1403/04/15):",
        reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
    )
    return ENTRY_DATE

async def entry_date(update: Update, context: ContextTypes.DEFAULT_TYPE):
    if update.message.text.strip() == "🔙 بازگشت":
        c.execute("SELECT id, name FROM Hotels")
        hotels = c.fetchall()
        keyboard = [[InlineKeyboardButton(h[1], callback_data=f"hotel_{h[0]}")] for h in hotels]
        keyboard.append([InlineKeyboardButton("🔙 بازگشت به انتخاب شهر", callback_data="start_reserve")])
        await update.message.reply_text(
            "لطفاً یک هتل را انتخاب کنید:",
            reply_markup=InlineKeyboardMarkup(keyboard)
        )
        return HOTEL_SELECTION
    context.user_data['entry_date'] = update.message.text
    keyboard = [["1 شب", "2 شب"], ["3 شب", "4 شب"], ["5 شب به بالا"]]
    await update.message.reply_text(
        "تعداد شب اقامت را انتخاب کنید:",
        reply_markup=ReplyKeyboardMarkup(keyboard + [["🔙 بازگشت"]], one_time_keyboard=True)
    )
    return NIGHTS_COUNT

async def nights_count(update: Update, context: ContextTypes.DEFAULT_TYPE):
    text = update.message.text.strip()

    if text == "🔙 بازگشت":
        keyboard = [["🔙 بازگشت"]]
        await update.message.reply_text(
            "لطفاً تاریخ ورود را وارد کنید (مثلاً 1403/04/15):",
            reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
        )
        return ENTRY_DATE

    if text == "5 شب به بالا":
        await update.message.reply_text(
            "لطفاً تعداد دقیق شب‌های اقامت را وارد کنید (به عدد):",
            reply_markup=ReplyKeyboardMarkup([["🔙 بازگشت"]], one_time_keyboard=True)
        )
        return CUSTOM_NIGHTS_COUNT
    else:
        context.user_data['nights_count'] = text
        room_types = context.user_data.get('room_type_options', ["دو تخته", "سوئیت"])
        keyboard = [[rt] for rt in room_types]
        await update.message.reply_text(
            "نوع اتاق را انتخاب کنید:",
            reply_markup=ReplyKeyboardMarkup(keyboard + [["🔙 بازگشت"]], one_time_keyboard=True)
        )
        return ROOM_TYPE

async def custom_nights_count(update: Update, context: ContextTypes.DEFAULT_TYPE):
    text = update.message.text.strip()
    if text == "🔙 بازگشت":
        keyboard = [["1 شب", "2 شب"], ["3 شب", "4 شب"], ["5 شب به بالا"]]
        await update.message.reply_text(
            "تعداد شب اقامت را انتخاب کنید:",
            reply_markup=ReplyKeyboardMarkup(keyboard + [["🔙 بازگشت"]], one_time_keyboard=True)
        )
        return NIGHTS_COUNT
    try:
        nights = int(text)
        if nights < 5:
            await update.message.reply_text(
                "لطفاً عددی بزرگ‌تر یا مساوی 5 وارد کنید:",
                reply_markup=ReplyKeyboardMarkup([["🔙 بازگشت"]], one_time_keyboard=True)
            )
            return CUSTOM_NIGHTS_COUNT
        context.user_data['nights_count'] = str(nights) + " شب"
        room_types = context.user_data.get('room_type_options', ["دو تخته", "سوئیت"])
        keyboard = [[rt] for rt in room_types]
        await update.message.reply_text(
            "نوع اتاق را انتخاب کنید:",
            reply_markup=ReplyKeyboardMarkup(keyboard + [["🔙 بازگشت"]], one_time_keyboard=True)
        )
        return ROOM_TYPE
    except ValueError:
        await update.message.reply_text(
            "لطفاً یک عدد معتبر وارد کنید:",
            reply_markup=ReplyKeyboardMarkup([["🔙 بازگشت"]], one_time_keyboard=True)
        )
        return CUSTOM_NIGHTS_COUNT

async def room_type(update: Update, context: ContextTypes.DEFAULT_TYPE):
    text = update.message.text.strip()
    if text == "🔙 بازگشت":
        keyboard = [["1 شب", "2 شب"], ["3 شب", "4 شب"], ["5 شب به بالا"]]
        await update.message.reply_text(
            "تعداد شب اقامت را انتخاب کنید:",
            reply_markup=ReplyKeyboardMarkup(keyboard + [["🔙 بازگشت"]], one_time_keyboard=True)
        )
        return NIGHTS_COUNT
    context.user_data['room_type'] = text
    meal_options = context.user_data.get('meal_options', ["با غذا", "بدون غذا"])
    keyboard = [[mo] for mo in meal_options]
    await update.message.reply_text(
        "نوع غذا را انتخاب کنید:",
        reply_markup=ReplyKeyboardMarkup(keyboard + [["🔙 بازگشت"]], one_time_keyboard=True)
    )
    return MEAL_PLAN

async def meal_plan(update: Update, context: ContextTypes.DEFAULT_TYPE):
    text = update.message.text.strip()
    if text == "🔙 بازگشت":
        room_types = context.user_data.get('room_type_options', ["دو تخته", "سوئیت"])
        keyboard = [[rt] for rt in room_types]
        await update.message.reply_text(
            "نوع اتاق را انتخاب کنید:",
            reply_markup=ReplyKeyboardMarkup(keyboard + [["🔙 بازگشت"]], one_time_keyboard=True)
        )
        return ROOM_TYPE
    context.user_data['meal_plan'] = text
    hotel_id = context.user_data['hotel_id']
    c.execute("SELECT name, price_without_meal, price_with_meal FROM Hotels WHERE id=?", (hotel_id,))
    hotel = c.fetchone()
    price_per_night = hotel[2] if text == "با غذا" else hotel[1]
    nights = int(context.user_data['nights_count'].split()[0])
    total_price = price_per_night * nights
    context.user_data['total_price'] = total_price
    detail = f"""🏨 هتل: {hotel[0]}
📅 تاریخ ورود: {context.user_data['entry_date']}
🌙 تعداد شب: {context.user_data['nights_count']}
🛏 نوع اتاق: {context.user_data['room_type']}
🍽 نوع غذا: {context.user_data['meal_plan']}
💵 قیمت کل: {total_price} دلار"""
    context.user_data['reservation_detail'] = detail
    user_id = update.message.from_user.id
    username = update.message.from_user.username or "ناشناس"
    c.execute("SELECT phone_number FROM Users WHERE user_id=?", (user_id,))
    result = c.fetchone()
    phone = result[0] if result else "ثبت نشده"
    context.user_data['pending_reservation'] = {
        'type': 'hotel',
        'detail': detail,
        'username': username,
        'phone': phone,
        'user_id': user_id
    }
    await update.message.reply_text(f"""✅ فاکتور رزرو:
{detail}""")
    keyboard = [["بله", "لغو رزرو"]]
    await update.message.reply_text(
        "آیا از رزرو خود مطمئن هستید؟",
        reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
    )
    return CONFIRM_PAYMENT

async def confirm_payment(update: Update, context: ContextTypes.DEFAULT_TYPE):
    text = update.message.text.strip()
    if text == "بله":
        reservation = context.user_data.get('pending_reservation')
        if not reservation:
            await update.message.reply_text("❗ خطا در ثبت رزرو. لطفاً دوباره تلاش کنید.")
            return ConversationHandler.END

        detail = reservation['detail']
        user_id = reservation['user_id']
        phone = reservation['phone']
        if reservation['type'] == 'hotel':
            c.execute("INSERT INTO Reservations (username, phone_number, date, details) VALUES (?, ?, ?, ?)",
                      (reservation['username'], phone, context.user_data.get('entry_date', 'نامشخص'), detail))
        elif reservation['type'] == 'transport':
            c.execute("INSERT INTO TransportBookings (user_id, username, transport_type, origin, destination, travel_date, travel_time, price, status, booking_time) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, datetime('now'))",
                      (update.message.from_user.id, reservation['username'], context.user_data.get('transport_type', 'نامشخص'), 
                       context.user_data.get('origin', 'نامشخص'), context.user_data.get('destination', 'نامشخص'), 
                       context.user_data.get('transport_date', 'نامشخص'), context.user_data.get('transport_time', 'نامشخص'), 
                       context.user_data.get('transport_price', 0), "تأیید شده"))
        elif reservation['type'] == 'package':
            c.execute("INSERT INTO Reservations (username, phone_number, date, details) VALUES (?, ?, ?, ?)",
                      (reservation['username'], phone, context.user_data.get('package_date', 'نامشخص'), detail))
        conn.commit()

        await update.message.reply_text(
            "با تشکر از شما، رزرو شما توسط کارشناسان بررسی و در اسرع وقت به آن پاسخ داده می‌شود. با تشکر از صبر و شکیبایی شما.",
            reply_markup=ReplyKeyboardRemove()
        )

        ADMIN_IDS = [6212473130, 881691358]
        for admin_id in ADMIN_IDS:
            try:
                await context.bot.send_message(chat_id=admin_id, text=f"""📥 رزرو جدید:
{detail}
🆔 آیدی تلگرام: {user_id}
📞 شماره تلفن: {phone}""")  # اضافه شدن آیدی تلگرام و شماره تلفن به پیام ادمین
            except:
                pass
        context.user_data.pop('pending_reservation', None)
        return await show_main_menu(update, context, message_text="✅ رزرو با موفقیت انجام شد. لطفاً گزینه‌ای را انتخاب کنید:")
    elif text == "لغو رزرو":
        reservation = context.user_data.get('pending_reservation')
        if reservation:
            detail = f"{reservation['detail']}\n❌ وضعیت: لغو شده توسط کاربر"
            user_id = reservation['user_id']
            phone = reservation['phone']
            if reservation['type'] == 'hotel':
                c.execute("INSERT INTO Reservations (username, phone_number, date, details) VALUES (?, ?, ?, ?)",
                          (reservation['username'], phone, context.user_data.get('entry_date', 'نامشخص'), detail))
            elif reservation['type'] == 'transport':
                c.execute("INSERT INTO TransportBookings (user_id, username, transport_type, origin, destination, travel_date, travel_time, price, status, booking_time) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, datetime('now'))",
                          (update.message.from_user.id, reservation['username'], context.user_data.get('transport_type', 'نامشخص'), 
                           context.user_data.get('origin', 'نامشخص'), context.user_data.get('destination', 'نامشخص'), 
                           context.user_data.get('transport_date', 'نامشخص'), context.user_data.get('transport_time', 'نامشخص'), 
                           context.user_data.get('transport_price', 0), "لغو شده"))
            elif reservation['type'] == 'package':
                c.execute("INSERT INTO Reservations (username, phone_number, date, details) VALUES (?, ?, ?, ?)",
                          (reservation['username'], phone, context.user_data.get('package_date', 'نامشخص'), detail))
            conn.commit()
            context.user_data.pop('pending_reservation', None)
        await update.message.reply_text(
            "❌ رزرو لغو شد.",
            reply_markup=build_back_to_menu_keyboard()
        )
        return ConversationHandler.END
    else:
        await update.message.reply_text(
            "لطفاً یکی از گزینه‌های 'بله' یا 'لغو رزرو' را انتخاب کنید.",
            reply_markup=ReplyKeyboardMarkup([["بله", "لغو رزرو"]], one_time_keyboard=True)
        )
        return CONFIRM_PAYMENT

async def handle_main_menu_options(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    option = query.data
    if option == "transportation":
        c.execute("SELECT id, name, emoji FROM TransportTypes")
        transport_types = c.fetchall()
        keyboard = [[InlineKeyboardButton(f"{t[1]} {t[2] if t[2] else ''}", callback_data=f"transport_{t[0]}")] for t in transport_types]
        keyboard.append([InlineKeyboardButton("🔙 بازگشت به منوی اصلی", callback_data="back_to_main")])
        await query.edit_message_text(
            "لطفاً نوع حمل و نقل را انتخاب کنید:",
            reply_markup=InlineKeyboardMarkup(keyboard)
        )
        return TRANSPORT_SELECTION
    elif option == "support":
        await query.edit_message_text(
            "📞 پشتیبانی: با شماره 09123456789 تماس بگیرید یا پیام دهید.",
            reply_markup=build_back_to_menu_keyboard()
        )
        return ConversationHandler.END
    elif option == "about_us":
        await query.edit_message_text(
            "ℹ️ درباره ما: ربات زائریاب، همراه شما در رزرو هتل و حمل و نقل برای سفرهای زیارتی.",
            reply_markup=build_back_to_menu_keyboard()
        )
        return ConversationHandler.END
    
    elif option == "sim_card":  # اضافه کردن گزینه سیم‌کارت   
        return await start_sim_card(update, context)

async def handle_transport_selection(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    if query.data == "back_to_main":
        return await show_main_menu(update, context)
    transport_id = query.data.split("_")[1]
    c.execute("SELECT name FROM TransportTypes WHERE id=?", (transport_id,))
    transport_type = c.fetchone()[0]
    context.user_data['transport_type'] = transport_type
    keyboard = [["انتخاب خودم", "پکیج زیارتی"], ["🔙 بازگشت به منوی اصلی"]]
    await query.message.reply_text(
        "لطفاً یکی از گزینه‌های زیر را انتخاب کنید:",
        reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
    )
    return TRANSPORT_PACKAGE

async def handle_transport_package(update: Update, context: ContextTypes.DEFAULT_TYPE):
    choice = update.message.text.strip()
    if choice == "🔙 بازگشت به منوی اصلی":
        return await show_main_menu(update, context)
    if choice == "انتخاب خودم":
        context.user_data['transport_choice'] = choice
        c.execute("SELECT name FROM OriginCities")
        origins = c.fetchall()
        keyboard = [[InlineKeyboardButton(origin[0], callback_data=f"origin_{origin[0]}")] for origin in origins]
        keyboard.append([InlineKeyboardButton("🔙 بازگشت به منوی اصلی", callback_data="back_to_main")])
        await update.message.reply_text(
            f"حمل و نقل: {context.user_data['transport_type']}\nلطفاً شهر مبدأ را انتخاب کنید:",
            reply_markup=InlineKeyboardMarkup(keyboard)
        )
        return ORIGIN_SELECTION
    elif choice == "پکیج زیارتی":
        context.user_data['transport_choice'] = choice
        c.execute("SELECT id, name, description FROM PilgrimagePackages")
        packages = c.fetchall()
        keyboard = [[InlineKeyboardButton(f"{p[1]}", callback_data=f"package_{p[0]}")] for p in packages]
        keyboard.append([InlineKeyboardButton("🔙 بازگشت به منوی اصلی", callback_data="back_to_main")])
        await update.message.reply_text(
            "لطفاً پکیج زیارتی مورد نظر را انتخاب کنید:",
            reply_markup=InlineKeyboardMarkup(keyboard)
        )
        return PACKAGE_SELECTION

async def handle_origin_selection(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    if query.data == "back_to_main":
        return await show_main_menu(update, context)
    origin = query.data.split("_")[1]
    context.user_data['origin'] = origin
    c.execute("SELECT name FROM DestinationCities")
    destinations = c.fetchall()
    keyboard = [[InlineKeyboardButton(dest[0], callback_data=f"dest_{dest[0]}")] for dest in destinations]
    keyboard.append([InlineKeyboardButton("🔙 بازگشت به منوی اصلی", callback_data="back_to_main")])
    await query.edit_message_text(
        f"مبدأ: {origin}\nلطفاً شهر مقصد را انتخاب کنید:",
        reply_markup=InlineKeyboardMarkup(keyboard)
    )
    return DESTINATION_SELECTION

async def handle_destination_selection(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    if query.data == "back_to_main":
        return await show_main_menu(update, context)
    destination = query.data.split("_")[1]
    context.user_data['destination'] = destination
    keyboard = [["🔙 بازگشت"]]
    await query.message.reply_text(
        "لطفاً تاریخ سفر را وارد کنید (مثلاً 1403/04/15):",
        reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
    )
    return TRANSPORT_DATE

async def handle_transport_date(update: Update, context: ContextTypes.DEFAULT_TYPE):
    text = update.message.text.strip()
    if text == "🔙 بازگشت":
        c.execute("SELECT name FROM DestinationCities")
        destinations = c.fetchall()
        keyboard = [[InlineKeyboardButton(dest[0], callback_data=f"dest_{dest[0]}")] for dest in destinations]
        keyboard.append([InlineKeyboardButton("🔙 بازگشت به منوی اصلی", callback_data="back_to_main")])
        await update.message.reply_text(
            f"مبدأ: {context.user_data['origin']}\nلطفاً شهر مقصد را انتخاب کنید:",
            reply_markup=InlineKeyboardMarkup(keyboard)
        )
        return DESTINATION_SELECTION
    context.user_data['transport_date'] = text
    await update.message.reply_text(
        "لطفاً ساعت سفر را وارد کنید (مثلاً 14:00):",
        reply_markup=ReplyKeyboardMarkup([["🔙 بازگشت"]], one_time_keyboard=True)
    )
    return TRANSPORT_TIME

async def handle_transport_time(update: Update, context: ContextTypes.DEFAULT_TYPE):
    text = update.message.text.strip()
    if text == "🔙 بازگشت":
        await update.message.reply_text(
            "لطفاً تاریخ سفر را وارد کنید (مثلاً 1403/04/15):",
            reply_markup=ReplyKeyboardMarkup([["🔙 بازگشت"]], one_time_keyboard=True)
        )
        return TRANSPORT_DATE
    context.user_data['transport_time'] = text
    # محاسبه قیمت فرضی (می‌توانید منطق خود را اضافه کنید)
    price = 50.0  # قیمت ثابت فرضی، می‌توانید بر اساس نوع حمل و نقل تغییر دهید
    context.user_data['transport_price'] = price
    
    transport_type = context.user_data['transport_type']
    travel_date = context.user_data['transport_date']
    travel_time = context.user_data['transport_time']
    origin = context.user_data['origin']
    destination = context.user_data['destination']
    
    detail = f"""🚗 نوع: {transport_type}
📍 مبدأ: {origin}
🏁 مقصد: {destination}
📅 تاریخ: {travel_date}
⏰ ساعت: {travel_time}"""
    
    await update.message.reply_text(f"""✅ فاکتور رزرو حمل و نقل:
{detail}""")
    
    user_id = update.message.from_user.id
    username = update.message.from_user.username or "ناشناس"
    c.execute("SELECT phone_number FROM Users WHERE user_id=?", (user_id,))
    result = c.fetchone()
    phone = result[0] if result else "ثبت نشده"
    context.user_data['pending_reservation'] = {
        'type': 'transport',
        'detail': detail,
        'username': username,
        'phone': phone,
        'user_id': user_id
    }
    keyboard = [["بله", "لغو رزرو"]]
    await update.message.reply_text(
        "آیا از رزرو خود مطمئن هستید؟",
        reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
    )
    return CONFIRM_PAYMENT

async def handle_package_selection(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    if query.data == "back_to_main":
        return await show_main_menu(update, context)
    package_id = query.data.split("_")[1]
    c.execute("SELECT name, description FROM PilgrimagePackages WHERE id=?", (package_id,))
    package = c.fetchone()
    context.user_data['package_name'] = package[0]
    context.user_data['package_description'] = package[1]
    keyboard = [["🔙 بازگشت"]]
    await query.message.reply_text(
        f"🕌 پکیج زیارتی: {package[0]}\n📝 توضیحات: {package[1] if package[1] else 'ندارد'}\nلطفاً تاریخ سفر خود را وارد کنید (مثلاً 1403/04/15):",
        reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
    )
    return PACKAGE_DATE

async def handle_package_date(update: Update, context: ContextTypes.DEFAULT_TYPE):
    text = update.message.text.strip()
    if text == "🔙 بازگشت":
        c.execute("SELECT id, name, description FROM PilgrimagePackages")
        packages = c.fetchall()
        keyboard = [[InlineKeyboardButton(f"{p[1]}", callback_data=f"package_{p[0]}")] for p in packages]
        keyboard.append([InlineKeyboardButton("🔙 بازگشت به منوی اصلی", callback_data="back_to_main")])
        await update.message.reply_text(
            "لطفاً پکیج زیارتی مورد نظر را انتخاب کنید:",
            reply_markup=InlineKeyboardMarkup(keyboard)
        )
        return PACKAGE_SELECTION
    context.user_data['package_date'] = text
    await update.message.reply_text(
        "لطفاً ساعت سفر را وارد کنید (مثلاً 14:00):",
        reply_markup=ReplyKeyboardMarkup([["🔙 بازگشت"]], one_time_keyboard=True)
    )
    return PACKAGE_TIME

async def handle_package_time(update: Update, context: ContextTypes.DEFAULT_TYPE):
    text = update.message.text.strip()
    if text == "🔙 بازگشت":
        await update.message.reply_text(
            "لطفاً تاریخ سفر خود را وارد کنید (مثلاً 1403/04/15):",
            reply_markup=ReplyKeyboardMarkup([["🔙 بازگشت"]], one_time_keyboard=True)
        )
        return PACKAGE_DATE
    context.user_data['package_time'] = text
    detail = f"""🕌 پکیج زیارتی: {context.user_data['package_name']}
📅 تاریخ سفر: {context.user_data['package_date']}
⏰ ساعت: {text}"""
    user_id = update.message.from_user.id
    username = update.message.from_user.username or "ناشناس"
    c.execute("SELECT phone_number FROM Users WHERE user_id=?", (user_id,))
    result = c.fetchone()
    phone = result[0] if result else "ثبت نشده"
    context.user_data['pending_reservation'] = {
        'type': 'package',
        'detail': detail,
        'username': username,
        'phone': phone,
        'user_id': user_id
    }
    await update.message.reply_text(f"""✅ فاکتور رزرو پکیج زیارتی:
{detail}""")
    keyboard = [["بله", "لغو رزرو"]]
    await update.message.reply_text(
        "آیا از رزرو خود مطمئن هستید؟",
        reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
    )
    return CONFIRM_PAYMENT

async def cancel(update: Update, context: ContextTypes.DEFAULT_TYPE):
    await update.message.reply_text(
        "❌ عملیات لغو شد.",
        reply_markup=build_back_to_menu_keyboard()
    )
    return ConversationHandler.END

# تابع جدید برای شروع بخش سیم‌کارت
async def start_sim_card(update: Update, context: ContextTypes.DEFAULT_TYPE):
    await update.callback_query.answer()
    keyboard = [
        [
            InlineKeyboardButton("زین 🇮🇶", callback_data='operator_zain'),
            InlineKeyboardButton("آسیاسل 🇮🇶", callback_data='operator_asia')
        ],
        [InlineKeyboardButton("🔙 بازگشت به منوی اصلی", callback_data='back_to_main')]
    ]
    await update.callback_query.edit_message_text(
        "لطفاً اپراتور مورد نظر خود را انتخاب کنید:",
        reply_markup=InlineKeyboardMarkup(keyboard)
    )
    return SIM_CARD_OPERATOR

# تابع جدید برای مدیریت انتخاب اپراتور
async def handle_sim_card_operator(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    if query.data == 'back_to_main':
        return await show_main_menu(update, context)
    
    
    # استخراج کلید اپراتور و نگاشت به نام فارسی
    op_key = query.data.split('_')[1]  # 'zain' یا 'asia'
    map_op = {'zain': 'زین', 'asia': 'آسیاسل'}
    operator_name = map_op.get(op_key, op_key)
    context.user_data['sim_operator'] = operator_name
    
    keyboard = [
        [
            InlineKeyboardButton("📲 خرید سیم‌کارت", callback_data='service_purchase'),
            InlineKeyboardButton("💳 شارژ", callback_data='service_recharge')
        ],
        [InlineKeyboardButton("🔙 بازگشت", callback_data='sim_card')]
    ]
    await query.edit_message_text(
        f"اپراتور: {operator_name}\nلطفاً نوع سرویس را انتخاب کنید:",
        reply_markup=InlineKeyboardMarkup(keyboard)
    )
    return SIM_CARD_SERVICE

# تابع جدید برای مدیریت انتخاب نوع سرویس (خرید یا شارژ)
async def handle_sim_card_service(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    if query.data == 'sim_card':
        return await start_sim_card(update, context)
    if query.data == 'back_to_main':
        return await show_main_menu(update, context)
    
    service = query.data.split('_')[1]  # استخراج نوع سرویس (purchase یا recharge)
    context.user_data['sim_service'] = service
    operator = context.user_data['sim_operator']
    
    if service == 'purchase':
        # استخراج شماره‌های موجود از دیتابیس (فقط شماره‌هایی که فروخته نشده‌اند)
        c.execute("SELECT id, number FROM SimCardNumbers WHERE operator=? AND is_sold=0", (operator,))
        numbers = c.fetchall()
        if not numbers:
            await query.edit_message_text(
                f"❌ متأسفانه شماره‌ای برای اپراتور {operator} موجود نیست.\nلطفاً بعداً تلاش کنید.",
                reply_markup=build_back_to_menu_keyboard()
            )
            return ConversationHandler.END
        
        keyboard = [[InlineKeyboardButton(num[1], callback_data=f"number_{num[0]}")] for num in numbers]
        keyboard.append([InlineKeyboardButton("🔙 بازگشت", callback_data='operator_' + operator.lower())])
        await query.edit_message_text(
            f"📱 شماره‌های موجود برای اپراتور {operator}:\nلطفاً شماره مورد نظر خود را انتخاب کنید:",
            reply_markup=InlineKeyboardMarkup(keyboard)
        )
        return SIM_CARD_PURCHASE
    else:  # recharge
        keyboard = [
            [InlineKeyboardButton("5000 دینار", callback_data='recharge_5000')],
            [InlineKeyboardButton("10000 دینار", callback_data='recharge_10000')],
            [InlineKeyboardButton("🔙 بازگشت", callback_data='operator_' + operator.lower())]
        ]
        await query.edit_message_text(
            f"💳 شارژ برای اپراتور {operator}:\nلطفاً مقدار شارژ را انتخاب کنید:",
            reply_markup=InlineKeyboardMarkup(keyboard)
        )
        return SIM_CARD_RECHARGE

# تابع جدید برای مدیریت انتخاب شماره برای خرید
async def handle_sim_card_purchase(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    if query.data == 'back_to_main':
        return await show_main_menu(update, context)
    if 'operator_' in query.data:
        return await handle_sim_card_operator(update, context)
    
    number_id = query.data.split('_')[1]
    c.execute("SELECT number FROM SimCardNumbers WHERE id=?", (number_id,))
    number = c.fetchone()[0]
    context.user_data['sim_number'] = number
    context.user_data['sim_price'] = 10.0  # قیمت فرضی برای خرید سیم‌کارت (می‌توانید تغییر دهید)
    
    operator = context.user_data['sim_operator']
    detail = f"""📱 خرید سیم‌کارت
اپراتور: {operator}
شماره: {number}
قیمت: {context.user_data['sim_price']} دلار"""
    context.user_data['sim_detail'] = detail
    
    await query.edit_message_text(
        f"✅ فاکتور خرید سیم‌کارت:\n{detail}",
        reply_markup=None
    )
    keyboard = [["بله", "لغو رزرو"]]
    await query.message.reply_text(
        "آیا از خرید خود مطمئن هستید؟",
        reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
    )
    return SIM_CARD_CONFIRM

# تابع جدید برای مدیریت انتخاب مقدار شارژ
async def handle_sim_card_recharge(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    await query.answer()
    if query.data == 'back_to_main':
        return await show_main_menu(update, context)
    if 'operator_' in query.data:
        return await handle_sim_card_operator(update, context)
    
    recharge_amount = query.data.split('_')[1]
    context.user_data['recharge_amount'] = recharge_amount
    context.user_data['sim_price'] = 5.0 if recharge_amount == '5000' else 10.0  # قیمت فرضی برای شارژ
    
    operator = context.user_data['sim_operator']
    detail = f"""💳 شارژ سیم‌کارت
اپراتور: {operator}
مقدار: {recharge_amount} دینار
قیمت: {context.user_data['sim_price']} دلار"""
    context.user_data['sim_detail'] = detail
    
    await query.edit_message_text(
        f"✅ فاکتور شارژ سیم‌کارت:\n{detail}",
        reply_markup=None
    )
    keyboard = [["بله", "لغو رزرو"]]
    await query.message.reply_text(
        "آیا از شارژ خود مطمئن هستید؟",
        reply_markup=ReplyKeyboardMarkup(keyboard, one_time_keyboard=True)
    )
    return SIM_CARD_CONFIRM

# تابع جدید برای مدیریت تأیید نهایی سفارش سیم‌کارت
async def handle_sim_card_confirm(update: Update, context: ContextTypes.DEFAULT_TYPE):
    choice = update.message.text.strip()
    if choice == "لغو رزرو":
        await update.message.reply_text(
            "❌ رزرو شما لغو شد.",
            reply_markup=build_main_menu_keyboard()
        )
        return ConversationHandler.END
    elif choice == "بله":
        user_id = update.message.from_user.id
        username = update.message.from_user.username or "ناشناس"
        c.execute("SELECT phone_number FROM Users WHERE user_id=?", (user_id,))
        result = c.fetchone()
        phone = result[0] if result else "ثبت نشده"
        
        sim_type = context.user_data['sim_operator']
        order_type = 'buy' if context.user_data['sim_service'] == 'purchase' else 'recharge'
        detail = context.user_data['sim_detail']
        status = "تأیید شده"
        order_time = str(update.message.date)  # زمان سفارش
        
        # ذخیره سفارش در دیتابیس
        c.execute("""
            INSERT INTO SimCardOrders (user_id, username, sim_type, order_type, detail, status, order_time)
            VALUES (?, ?, ?, ?, ?, ?, ?)
        """, (user_id, username, sim_type, order_type, detail, status, order_time))
        conn.commit()
        
        # اگر خرید سیم‌کارت باشد، وضعیت شماره را به "فروخته شده" تغییر می‌دهیم
        if order_type == 'buy':
            number = context.user_data.get('sim_number')
            if number:
                c.execute("UPDATE SimCardNumbers SET is_sold=1 WHERE number=?", (number,))
                conn.commit()
        
        await update.message.reply_text(
            "✅ سفارش شما با موفقیت ثبت شد.",
            reply_markup=build_main_menu_keyboard()
        )
        return ConversationHandler.END


async def main():
    app = ApplicationBuilder().token("8167886393:AAH7RFVy9rNuoXv3nSpvzJvYjD25ErLhHzQ").build()

    conv_handler = ConversationHandler(
        entry_points=[
            CommandHandler("start", start),
            CallbackQueryHandler(start_reserve, pattern="^start_reserve$"),
            CallbackQueryHandler(show_main_menu, pattern="^back_to_main$"),
            CallbackQueryHandler(handle_main_menu_options, pattern="^(transportation|support|about_us|sim_card)$"),
        ],
        states={
            CHECK_CHANNEL_MEMBERSHIP: [
                CallbackQueryHandler(check_channel_membership, pattern="^joined_channel$")
            ],
            ASK_PHONE: [MessageHandler(filters.CONTACT, save_phone)],
            CITY_SELECTION: [
                CallbackQueryHandler(handle_city_selection, pattern="^select_city_.*$"),
                CallbackQueryHandler(handle_city_selection, pattern="^back_to_main$")
            ],
            HOTEL_SELECTION: [
                CallbackQueryHandler(handle_hotel_selection, pattern="^hotel_.*$"),
                CallbackQueryHandler(start_reserve, pattern="^start_reserve$")
            ],
            ENTRY_DATE: [MessageHandler(filters.TEXT & ~filters.COMMAND, entry_date)],
            NIGHTS_COUNT: [MessageHandler(filters.TEXT & ~filters.COMMAND, nights_count)],
            CUSTOM_NIGHTS_COUNT: [MessageHandler(filters.TEXT & ~filters.COMMAND, custom_nights_count)],
            ROOM_TYPE: [MessageHandler(filters.TEXT & ~filters.COMMAND, room_type)],
            MEAL_PLAN: [MessageHandler(filters.TEXT & ~filters.COMMAND, meal_plan)],
            CONFIRM_PAYMENT: [MessageHandler(filters.TEXT & ~filters.COMMAND, confirm_payment)],
            TRANSPORT_SELECTION: [CallbackQueryHandler(handle_transport_selection, pattern="^transport_.*$")],
            TRANSPORT_DATE: [MessageHandler(filters.TEXT & ~filters.COMMAND, handle_transport_date)],
            TRANSPORT_TIME: [MessageHandler(filters.TEXT & ~filters.COMMAND, handle_transport_time)],
            TRANSPORT_PACKAGE: [MessageHandler(filters.TEXT & ~filters.COMMAND, handle_transport_package)],
            ORIGIN_SELECTION: [CallbackQueryHandler(handle_origin_selection, pattern="^origin_.*$")],
            DESTINATION_SELECTION: [CallbackQueryHandler(handle_destination_selection, pattern="^dest_.*$")],
            PACKAGE_SELECTION: [CallbackQueryHandler(handle_package_selection, pattern="^package_.*$")],
            PACKAGE_DATE: [MessageHandler(filters.TEXT & ~filters.COMMAND, handle_package_date)],
            PACKAGE_TIME: [MessageHandler(filters.TEXT & ~filters.COMMAND, handle_package_time)],
            
                SIM_CARD_OPERATOR: [CallbackQueryHandler(handle_sim_card_operator)],
            SIM_CARD_SERVICE: [CallbackQueryHandler(handle_sim_card_service)],
            SIM_CARD_PURCHASE: [CallbackQueryHandler(handle_sim_card_purchase)],
            SIM_CARD_RECHARGE: [CallbackQueryHandler(handle_sim_card_recharge)],
            SIM_CARD_CONFIRM: [MessageHandler(filters.TEXT & ~filters.COMMAND, handle_sim_card_confirm)]
        },
        fallbacks=[CallbackQueryHandler(show_main_menu, pattern='^back_to_main')],
)

    app.add_handler(conv_handler)
    
    await app.run_polling()

if __name__ == "__main__":
    asyncio.run(main())
